aboutsummaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorrub <rub@piwigo.org>2007-03-16 18:49:19 +0000
committerrub <rub@piwigo.org>2007-03-16 18:49:19 +0000
commit1a3660405a6856bca55932900e18edd5b5e6d20b (patch)
tree6759a9129ed371803b7a9bfe8fb65671fe4c7e92 /include
parent837138918295869327ea93d06d508d7c26c2ebea (diff)
Add the last (before 1.8) tabsheet on administration menu (Waiting elements).
Small change way mail function. git-svn-id: http://piwigo.org/svn/trunk@1915 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'include')
-rw-r--r--include/functions_mail.inc.php8
1 files changed, 5 insertions, 3 deletions
diff --git a/include/functions_mail.inc.php b/include/functions_mail.inc.php
index 07764f006..92d5ead6a 100644
--- a/include/functions_mail.inc.php
+++ b/include/functions_mail.inc.php
@@ -327,7 +327,8 @@ order by
* - group_id: mail are sent to group with this Id
* - email_format: mail format
* - keyargs_subject: mail subject on l10n_args format
* - tpl_shortname: short template name without extension
* - assign_vars: array used to assign_vars to mail template
* - language_selected: send mail only to user with this selected language
*
@@ -335,7 +336,8 @@ order by
*/
function pwg_mail_group(
$group_id, $email_format, $keyargs_subject,
- $tpl_shortname, $assign_vars = array(), $language_selected = '')
+ $dirname, $tpl_shortname,
+ $assign_vars = array(), $language_selected = '')
{
global $conf;
$return = true;
@@ -407,7 +409,7 @@ WHERE
$mail_template = get_mail_template($email_format, $elem);
$mail_template->set_filename($tpl_shortname,
- (IN_ADMIN ? 'admin/' : '').$tpl_shortname.'.tpl');
+ (empty($dirname) ? '' : $dirname.'/').$tpl_shortname.'.tpl');
$mail_template->assign_vars($assign_vars);
$return = pwg_mail
@@ -327,7 +327,8 @@ order by
* - email_format: mail format
* - keyargs_subject: mail subject on l10n_args format
- * - tpl_shortname: short template name without extension
+ * - dirname: short name of directory including template
+ * - tpl_shortname: short template name without extension
* - assign_vars: array used to assign_vars to mail template
* - language_selected: send mail only to user with this selected language